@@ -1,4 +1,7 @@
 #!/bin/env python
+from __future__ import division
+from builtins import str, range, object
+from past.utils import old_div
 import logging
 from collections import namedtuple
 import os
@@ -7,13 +10,13 @@ import base64
 import re
 import string
 from azure.storage.file import FileService
-from azure.storage.cloudstorageaccount import CloudStorageAccount
+from azure.storage.common.cloudstorageaccount import CloudStorageAccount
 from azure.mgmt.compute import ComputeManagementClient
 from azure.mgmt.network import NetworkManagementClient
 from azure.common.credentials import ServicePrincipalCredentials
 from metric_utils import MetricUtils
 from haikunator import Haikunator
-from azure.servicebus.servicebusservice import ServiceBusService
+from azure.servicebus.control_client import ServiceBusService
 from servicebus_utils import ServiceBusUtils
 import configparser
 from shutil import copyfile
@@ -24,7 +27,7 @@ logger = logging.getLogger('autoscaler.' + __name__)
 logger.setLevel(logging.DEBUG)
 
 
-class as_cloud():
+class as_cloud(object):
     def __init__(self):
         self.logger = logger
         self.azure_dir = os.path.expanduser('~') + '/.azure'
@@ -719,7 +722,7 @@ class as_cloud():
 
             if metric_type == 'sum':
                 for i in range(len(mylist)):
-                    mylist[i] = (mylist[i][0], mylist[i][1], mylist[i][2]/metric_period)
+                    mylist[i] = (mylist[i][0], mylist[i][1], old_div(mylist[i][2],metric_period))
 
             if len(mylist) > 0:
                 results = sorted(mylist, key=lambda x: x[0])
@@ -727,7 +730,7 @@ class as_cloud():
                     results, key=lambda item: item[2])
                 name, max_time, max_value = max(
                     results, key=lambda item: item[2])
-                avg_value = (sum(x[2] for x in results) / len(mylist))
+                avg_value = (old_div(sum(x[2] for x in results), len(mylist)))
                 self.logger.debug("%s (%s) => %s/%s/%s" % (rg_vmname_combo_inst_id, name, min_value, max_value, avg_value))
 
                 result = self.Results(
@@ -746,7 +749,7 @@ class as_cloud():
                         min=0,
                         max=0,
                         avg=0,
-                        cnt=int(int(period)/int(metric_period)),
+                        cnt=int(old_div(int(period),int(metric_period))),
                         inst=instance_id
                     )
                     return result
