@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 from __future__ import print_function
 import sys
-from token_api import Token_api as token_api
+from csr_cloud.token_api import Token_api as token_api
 
 def main(argv):
 
